@@ -94,6 +94,11 @@ EOF
 	print $fh <<"EOF";
 \$ENV{GIT_DIR}    = '.git' unless exists \$ENV{GIT_DIR};
 \$ENV{GIT_CONFIG} = "\$ENV{GIT_DIR}/config";
+EOF
+
+        # Reset HOME to avoid reading ~/.gitconfig
+	print $fh <<"EOF";
+\$ENV{HOME}       = '';
 EOF
 
         # Hooks on Windows are invoked indirectly.
